%      fuzzy

function fuzzyStruct = genFuzzyStruct(vectors, wordNames)
    %parameters init
    [n_words, n_components] = size(vectors);
    mf_width = 20; % width of the membership function
    range = 40; % input variables range
    for i = 1:n_components
        freq_names(i,:) = ['freq', num2str(i)];
    end

    fuzzyStruct = newfis('word_recognition');

    %input vars and funcs init
    for i = 1:n_components % vector components
        min = vectors(1, i);
        max = vectors(1, i);
        for j = 2:n_words
            if vectors(j, i) < min
                min = vectors(j, i);
            elseif vectors(j, i) > max
                max = vectors(j, i);
            end
        end
        fuzzyStruct = addvar(fuzzyStruct, 'input', freq_names(i,:), [min-range max+range]);
        for j = 1:n_words, % words
            fuzzyStruct = addmf(fuzzyStruct, 'input', i, wordNames(j,:), 'trimf', [vectors(j,i)-mf_width, vectors(j,i), vectors(j,i)+mf_width]);  
        end
    end
    
    %output vars and funcs init
    for i = 1:n_words
        fuzzyStruct = addvar(fuzzyStruct, 'output', wordNames(i,:), [0 2]);
        fuzzyStruct = addmf(fuzzyStruct, 'output', i, wordNames(i,:), 'trimf', [0 1 2]);
    end
    
    %rules init
    E = eye(n_words);
    x = [1:n_words];
    x = rot90(x, -1);
    X = repmat(x, 1, n_components);
    S = ones(n_words, 2);
    ruleList = cat(2, X, E, S);
    fuzzyStruct = addrule(fuzzyStruct, ruleList);